@@ -4,21 +4,20 @@ import textwrap
 
 from . import Archive
 
-__version__ = 'wbsv 0.2.0'
+__version__ = 'wbsv 0.2.3'
+
+
+def natural_num(n):
+    """Judge whether numstr is positive or not."""
+    if int(n) < 1:
+        print("[!]Err: num {} should be more than 0.".format(n),
+              file=sys.stderr)
+        exit(1)
+    return n
 
 
 def parse_args():
     """Parse arguments."""
-    def natural_num(n):
-        if not n.isdecimal():
-            print("[!]Err: num {} should be positive integer.".format(n),
-                  file=sys.stderr)
-            exit(1)
-        elif int(n) < 1:
-            print("[!]Err: num {} should be more than 0.".format(n),
-                  file=sys.stderr)
-            exit(1)
-        return int(n)
     parser = argparse.ArgumentParser(
         prog='wbsv',
         formatter_class=argparse.RawDescriptionHelpFormatter,
@@ -35,27 +34,31 @@ def parse_args():
 
     parser.add_argument('url',  metavar='url', nargs='*',
                         help='Saving pages in order.')
-    parser.add_argument('-v', '--version', action='version',
+    parser.add_argument('-V', '--version', action='version',
                         version=__version__,
                         help='Show version and exit')
     parser.add_argument('-r', '--retry', default=3,
-                        type=natural_num, metavar='cnt',
+                        metavar='cnt', type=int,
                         help='Set a retry limit on failed save.')
     parser.add_argument('-t', '--only_target', action='store_true',
                         help='Save just target webpage(s).')
-    parser.add_argument('-L', '--level', default=0,
-                        type=natural_num, metavar='lv',
+    parser.add_argument('-L', '--level', default=1,
+                        metavar='lv', type=int,
                         help='Set maximum recursion depth.')
+    parser.add_argument('-d', '--dry_run', action='store_true', default=False,
+                        help='Running without saving (dry-run mode)')
     args = parser.parse_args()
     urls = [i for i in args.url if Archive.is_url(i)]
     if args.url != urls:
         print("[!]invalid url format", file=sys.stderr)
         exit(1)
+
     param = {
-        "retry": args.retry,
+        "retry": natural_num(args.retry),
         "urls": urls,
         "only-target": args.only_target,
+        "dry-run": args.dry_run,
         "errout": sys.stderr,
         "out": sys.stdout,
-        "level": args.level}
+        "level": natural_num(args.level)}
     return param
